@@ -3,7 +3,7 @@
 
 #include <QWidget>
 #include <QVBoxLayout>
-#include <Phonon>
+#include <phonon>
 
 class SymfonieMediaPlayer;
 
